==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/az.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Bu serverdə, serverlərarası yayımlanma aktiv deyil",
    "The mountpoint name contains invalid characters." : "Bərkidilmə nöqtəsinin adında yalnış simvollar mövcuddur. ",
    "Invalid or untrusted SSL certificate" : "Yalnış yada inam listindən kənar SSL sertifikatı",
    "Could not authenticate to remote share, password might be wrong" : "Uzaqda olan paylaşımın əslliyini yoxlamaq olmur və ola bilər ki, şifrə yalnışdır. ",
    "Storage not valid" : "Depo etibarlı deyil",
    "Couldn't add remote share" : "Uzaqda olan yayımlanmanı əlavə etmək mümkün olmadı",
    "Shared with you" : "Sizinlə yayımlanan",
    "Shared with others" : "Hər kəsə yayımlanmış",
    "Shared by link" : "Link tərəfindən paylaşılıb",
    "Nothing shared with you yet" : "Hələki sizinlə heç bir şey paylaşılmayıb",
    "Files and folders others share with you will show up here" : "Digərlərinin sizinlə paylaşdığı fayllar və qovluqlar burda göstəriləcək",
    "Nothing shared yet" : "Paylaşılan heçnə yoxdur",
    "Files and folders you share will show up here" : "Sizin tərəfinizdən paylaşılmış fayllar və qovluqlar burda göstəriləcək",
    "No shared links" : "Paylaşılmış linklər yoxdur ",
    "Files and folders you share by link will show up here" : "Link vasitəsilə sizin tərəfinizdən paylaşılmış fayllar və qovluqlar burda göstəriləcək",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Siz uzaq paylaşımı əlavə etmək istəyirsinizmi {name} dan {owner}@{remote}?",
    "Remote share" : "Uzaq yayımlanma",
    "Remote share password" : "Uzaq yayımlanma şifrəsi",
    "Cancel" : "Dayandır",
    "Add remote share" : "Uzaq yayımlanmanı əlavə et",
    "You can upload into this folder" : "Siz bu qovluğun içinə yükləyə bilərsiniz",
    "No ownCloud installation (7 or higher) found at {remote}" : "Yüklənmiş (7 yada yuxarı) ownCloud {uzaq} unvanında tapılmadı ",
    "Invalid ownCloud url" : "Yalnış ownCloud url-i",
    "Shared by" : "Tərəfindən yayımlanıb",
    "Sharing" : "Paylaşılır",
    "A file or folder has been <strong>shared</strong>" : "Fayl və ya direktoriya <strong>yayımlandı</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fayl yada qovluq ünvanından yayımlandı <strong>digər serverə</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ümumi paylaşılmış fayl yada qovluq <strong>endirilmişdir</strong>",
    "You received a new remote share from %s" : "Siz %s ünvanından yeni uzaq paylaşım aldınız",
    "%1$s accepted remote share %2$s" : "%1$s qəbul etdi uzaq paylaşım %2$s",
    "%1$s declined remote share %2$s" : "%1$s təkzib etdi uzaq paylaşımı %2$s",
    "%1$s unshared %2$s from you" : "%1$s paylaşımı dayandırıldı %2$s sizin tərəfinizdən",
    "Public shared folder %1$s was downloaded" : "Ümumi paylaşılmış qovluq %1$s endirilmişdir",
    "Public shared file %1$s was downloaded" : "Ümumi paylaşılmış fayl %1$s endirilmişdir",
    "You shared %1$s with %2$s" : "Siz yayımladınız %1$s - i %2$s ilə",
    "You shared %1$s with group %2$s" : "Siz yayımladınız %1$s qrupu ilə %2$s",
    "You shared %1$s via link" : "Siz yayımladınız %1$s link ilə",
    "%2$s shared %1$s with you" : "%2$s yayımlanıb %1$s sizinlə",
    "Shares" : "Yayımlanmalar",
    "This share is password-protected" : "Bu paylaşım şifrə ilə müdafiəlidir",
    "The password is wrong. Try again." : "Şifrə yalnışdır. Yenidən cəhd edin.",
    "Password" : "Şifrə",
    "No entries found in this folder" : "Bu qovluqda heç bir verilən tapılmadı",
    "Name" : "Ad",
    "Share time" : "Paylaşım vaxtı",
    "Sorry, this link doesn’t seem to work anymore." : "Üzr istəyirik, bu link artıq işlək deyil.",
    "Reasons might be:" : "Səbəblər ola bilər:",
    "the item was removed" : "bölüm silinmişdir",
    "the link expired" : "linkin vaxtı bitmişdir",
    "sharing is disabled" : "paylaşım dayandırılmışdır",
    "For more info, please ask the person who sent this link." : "Ətraflı məlumat üçün, xahiş olunur linkin kim tərəfindən göndərilməsini soruşun.",
    "Add to your ownCloud" : "Öz ownCloud-nuza əlavə edin",
    "Download" : "Yüklə",
    "Download %s" : "Endir %s",
    "Direct link" : "Birbaşa link",
    "Federated Cloud Sharing" : "Federal Cloud Paylaşım",
    "Open documentation" : "Sənədləri aç",
    "Allow users on this server to send shares to other servers" : "Bu serverdən digər serverlərə istifadəçilər tərəfindən paylaşımın göndərilməsinə izin vermək",
    "Allow users on this server to receive shares from other servers" : "Digər serverlərdən bu serverə istifadəçilər tərəfindən paylaşımın ötürülməsinə izin vermək",
    "Public shared file %1$s was downloaded" : "Ümumi paylaşılmış fayl %1$s endirilmişdir",
    "Public shared folder %1$s was downloaded" : "Ümumi paylaşılmış qovluq %1$s endirilmişdir"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/az.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Bu serverdə, serverlərarası yayımlanma aktiv deyil",
    "The mountpoint name contains invalid characters." : "Bərkidilmə nöqtəsinin adında yalnış simvollar mövcuddur. ",
    "Invalid or untrusted SSL certificate" : "Yalnış yada inam listindən kənar SSL sertifikatı",
    "Could not authenticate to remote share, password might be wrong" : "Uzaqda olan paylaşımın əslliyini yoxlamaq olmur və ola bilər ki, şifrə yalnışdır. ",
    "Storage not valid" : "Depo etibarlı deyil",
    "Couldn't add remote share" : "Uzaqda olan yayımlanmanı əlavə etmək mümkün olmadı",
    "Shared with you" : "Sizinlə yayımlanan",
    "Shared with others" : "Hər kəsə yayımlanmış",
    "Shared by link" : "Link tərəfindən paylaşılıb",
    "Uploading..." : "Serverə yüklənir...",
    "Nothing shared with you yet" : "Hələki sizinlə heç bir şey paylaşılmayıb",
    "Files and folders others share with you will show up here" : "Digərlərinin sizinlə paylaşdığı fayllar və qovluqlar burda göstəriləcək",
    "Nothing shared yet" : "Paylaşılan heçnə yoxdur",
    "Files and folders you share will show up here" : "Sizin tərəfinizdən paylaşılmış fayllar və qovluqlar burda göstəriləcək",
    "No shared links" : "Paylaşılmış linklər yoxdur ",
    "Files and folders you share by link will show up here" : "Link vasitəsilə sizin tərəfinizdən paylaşılmış fayllar və qovluqlar burda göstəriləcək",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Siz uzaq paylaşımı əlavə etmək istəyirsinizmi {name} dan {owner}@{remote}?",
    "Remote share" : "Uzaq yayımlanma",
    "Remote share password" : "Uzaq yayımlanma şifrəsi",
    "Cancel" : "Dayandır",
    "Add remote share" : "Uzaq yayımlanmanı əlavə et",
    "You can upload into this folder" : "Siz bu qovluğun içinə yükləyə bilərsiniz",
    "No ownCloud installation (7 or higher) found at {remote}" : "Yüklənmiş (7 yada yuxarı) ownCloud {uzaq} unvanında tapılmadı ",
    "Invalid ownCloud url" : "Yalnış ownCloud url-i",
    "Share" : "Paylaş",
    "Shared by" : "Tərəfindən yayımlanıb",
    "Sharing" : "Paylaşılır",
    "A file or folder has been <strong>shared</strong>" : "Fayl və ya direktoriya <strong>yayımlandı</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fayl yada qovluq ünvanından yayımlandı <strong>digər serverə</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ümumi paylaşılmış fayl yada qovluq <strong>endirilmişdir</strong>",
    "You received a new remote share from %s" : "Siz %s ünvanından yeni uzaq paylaşım aldınız",
    "%1$s accepted remote share %2$s" : "%1$s qəbul etdi uzaq paylaşım %2$s",
    "%1$s declined remote share %2$s" : "%1$s təkzib etdi uzaq paylaşımı %2$s",
    "%1$s unshared %2$s from you" : "%1$s paylaşımı dayandırıldı %2$s sizin tərəfinizdən",
    "Public shared folder %1$s was downloaded" : "Ümumi paylaşılmış qovluq %1$s endirilmişdir",
    "Public shared file %1$s was downloaded" : "Ümumi paylaşılmış fayl %1$s endirilmişdir",
    "You shared %1$s with %2$s" : "Siz yayımladınız %1$s - i %2$s ilə",
    "You shared %1$s with group %2$s" : "Siz yayımladınız %1$s qrupu ilə %2$s",
    "You shared %1$s via link" : "Siz yayımladınız %1$s link ilə",
    "%2$s shared %1$s with you" : "%2$s yayımlanıb %1$s sizinlə",
    "Shares" : "Yayımlanmalar",
    "This share is password-protected" : "Bu paylaşım şifrə ilə müdafiəlidir",
    "The password is wrong. Try again." : "Şifrə yalnışdır. Yenidən cəhd edin.",
    "Password" : "Şifrə",
    "No entries found in this folder" : "Bu qovluqda heç bir verilən tapılmadı",
    "Name" : "Ad",
    "Share time" : "Paylaşım vaxtı",
    "Sorry, this link doesn’t seem to work anymore." : "Üzr istəyirik, bu link artıq işlək deyil.",
    "Reasons might be:" : "Səbəblər ola bilər:",
    "the item was removed" : "bölüm silinmişdir",
    "the link expired" : "linkin vaxtı bitmişdir",
    "sharing is disabled" : "paylaşım dayandırılmışdır",
    "For more info, please ask the person who sent this link." : "Ətraflı məlumat üçün, xahiş olunur linkin kim tərəfindən göndərilməsini soruşun.",
    "Add to your ownCloud" : "Öz ownCloud-nuza əlavə edin",
    "Download" : "Yüklə",
    "Download %s" : "Endir %s",
    "Direct link" : "Birbaşa link"
},
"nplurals=2; plural=(n != 1);");
